Message

Enum Message 

pub(crate) enum Message {
Show 20 variants Key(KeyEvent), RadioUpdate(RadioState), RadioError(String), Disconnected, Reconnected, McpProgress { page: u16, total: u16, }, McpReadComplete(Vec<u8>), McpWriteComplete, McpByteWritten { offset: u16, value: u8, }, McpError(String), AprsStarted, AprsStopped, AprsEvent(AprsEvent), AprsMessageSent { addressee: String, text: String, message_id: String, }, AprsError(String), DStarStarted, DStarStopped, DStarEvent(DStarEvent), DStarError(String), Quit,
}
All events that can flow into the update loop.

Variants



Key(KeyEvent)



RadioUpdate(RadioState)



RadioError(String)



Disconnected



Reconnected



McpProgress

Fields

page: u16
total: u16


McpReadComplete(Vec<u8>)



McpWriteComplete



McpByteWritten

A single MCP byte was written successfully — update the in-memory cache without requiring a full re-read.

Fields

offset: u16
value: u8


McpError(String)



AprsStarted

The radio task has entered APRS mode successfully.



AprsStopped

The radio task has exited APRS mode.



AprsEvent(AprsEvent)

An APRS event was received from the radio task.



AprsMessageSent

An APRS message was sent and assigned a message ID for tracking.

Fields

addressee: String
text: String
message_id: String


AprsError(String)

Error from the APRS subsystem.



DStarStarted

The radio task has entered D-STAR gateway mode successfully.



DStarStopped

The radio task has exited D-STAR gateway mode.



DStarEvent(DStarEvent)

A D-STAR event was received from the radio task (gateway mode).



DStarError(String)

Error from the D-STAR subsystem.



Quit